@@ -85,7 +85,7 @@ module CacheStoreTests
   end
 end
 
-class TestNullStore < MiniTest::Test
+class TestNullStore < Minitest::Test
   def setup
     @_store = Sprockets::Cache::NullStore.new
     @store = Sprockets::Cache.new(Sprockets::Cache::NullStore.new)
@@ -99,7 +99,7 @@ class TestNullStore < MiniTest::Test
   include CacheStoreNullTests
 end
 
-class TestMemoryStore < MiniTest::Test
+class TestMemoryStore < Minitest::Test
   def setup
     @_store = Sprockets::Cache::MemoryStore.new
     @store = Sprockets::Cache.new(@_store)
@@ -132,7 +132,7 @@ class TestMemoryStore < MiniTest::Test
   end
 end
 
-class TestZeroMemoryStore < MiniTest::Test
+class TestZeroMemoryStore < Minitest::Test
   def setup
     @_store = Sprockets::Cache::MemoryStore.new(0)
     @store = Sprockets::Cache.new(@_store)
@@ -145,7 +145,7 @@ class TestZeroMemoryStore < MiniTest::Test
   include CacheStoreNullTests
 end
 
-class TestFileStore < MiniTest::Test
+class TestFileStore < Minitest::Test
   def setup
     @root = Dir::mktmpdir "sprockets-file-store"
     @_store = Sprockets::Cache::FileStore.new(@root)
@@ -180,7 +180,7 @@ class TestFileStore < MiniTest::Test
   include CacheStoreTests
 end
 
-class TestZeroFileStore < MiniTest::Test
+class TestZeroFileStore < Minitest::Test
   def setup
     @tmpdir = Dir::mktmpdir "sprockets-file-store-zero"
     @_store = Sprockets::Cache::FileStore.new(@tmpdir, 0)
